package de.cosmit.samuraj.toolbox.util;

import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.math.BigDecimal;
import java.util.Date;

import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.ss.util.CellRangeAddress;
import org.mozilla.javascript.NativeJavaObject;

/**
 * create a test xls:
<pre>
Test_51481_autofilter t = new Test_51481_autofilter();
t.start();
t.fillValues(true, true);
t.save();
</pre>
 *
 */
public class Test_51481_autofilter
{
	private HSSFWorkbook workbook;
	private HSSFSheet sheet;

	public void start()
	{
		workbook = new HSSFWorkbook();
		sheet = workbook.createSheet("Test");
	}
	
	public void fillValues(boolean filter, boolean size)
	{
		if (sheet == null)
		{
			return;
		}
		int i;
		HSSFRow row;
		row = sheet.createRow(0);
		addCell(row, 0, "Test1");
		addCell(row, 1, "Test2");
		addCell(row, 2, "Test3");
		row = sheet.createRow(1);
		addCell(row, 0, "aaa");
		addCell(row, 1, (Double)12.7);
		addCell(row, 2, (Double)120.7);
		row = sheet.createRow(2);
		addCell(row, 0, "aaa");
		addCell(row, 1, (Double)14.2);
		addCell(row, 2, (Double)98.7);
		row = sheet.createRow(3);
		addCell(row, 0, "bbb");
		addCell(row, 1, (Double)15.7);
		addCell(row, 2, (Double)10.7);
		row = sheet.createRow(4);
		addCell(row, 0, "bbb");
		addCell(row, 1, (Double)18.2);
		addCell(row, 2, (Double)18.7);
		if (filter)
		{
			sheet.setAutoFilter(new CellRangeAddress(0, 4, 0, 2));
		}
		if (size)
		{
			for (i = 0; i < 3; i++)
			{
				sheet.autoSizeColumn(i);
			}
		}
	}
	
	public void save()
	{
		if (workbook == null)
		{
			return;
		}
		FileOutputStream fileOut;
		try 
		{
			fileOut = new FileOutputStream("c:/temp/test_excel_HSSFPOI.xls");
			workbook.write(fileOut);
			fileOut.close();
		} 
		catch (FileNotFoundException e) 
		{
			e.printStackTrace();
		} 
		catch (IOException e) 
		{
			e.printStackTrace();
		}

	}
	
	private HSSFCell addCell(HSSFRow row, int colNum, Object value)
	{
		if (row == null || colNum < 0)
		{
			return null;
		}
		HSSFCell cell = row.createCell(colNum);
		if (value == null)
		{
		}
		else if (value instanceof String)
		{
			cell.setCellType(HSSFCell.CELL_TYPE_STRING);
			cell.setCellValue(workbook.getCreationHelper().createRichTextString((String) value));
		}
		else if (value instanceof Float)
		{
			cell.setCellValue((Float) value);
		}
		else if (value instanceof Integer)
		{
			cell.setCellValue((Integer) value);
		}
		else if (value instanceof Double)
		{
			cell.setCellValue((Double) value);
		}
		else if (value instanceof BigDecimal)
		{
			cell.setCellValue(((BigDecimal) value).doubleValue());
		}
		else if (value instanceof Date)
		{
			cell.setCellValue((Date) value);
		}
		else if (value instanceof Boolean)
		{
			cell.setCellValue((Boolean) value);
		}
		else if (value instanceof NativeJavaObject)
		{
			NativeJavaObject njo = (NativeJavaObject) value;
			Object jo = njo.unwrap();
			if (jo instanceof java.sql.Date)
			{
				cell.setCellValue((java.sql.Date) jo);
			}
			else
			{
				if (jo != null)
				{
					cell.setCellType(HSSFCell.CELL_TYPE_STRING);
					cell.setCellValue(jo.getClass().getCanonicalName());
				}
			}
		}
		else
		{
			cell.setCellType(HSSFCell.CELL_TYPE_STRING);
			cell.setCellValue(value.getClass().getCanonicalName());
		}
		return cell;
	}
}
